@@ -1,10 +1,13 @@
-
 from uuid import uuid4
 from datetime import datetime
 from threedi_api_client.api import ThreediApi
 from threedi_cmd.parser import ScenarioParser
 
 
+class MockedThreedimodel:
+    id = 14
+    schematisation_id = None
+
 def test_parser():
     # Note: smoke test parser (including jinja2-time template rendering)
     organisation = "61f5a464c35044c19bc7d4b42d7f58cb"
@@ -13,6 +16,7 @@ def test_parser():
 
     context = {
         "threedimodel_id": threedimodel_id,
+        "threedimodel": MockedThreedimodel(),
         "organisation_uuid": organisation,
         "simulation_name": simulation_name,
         "datetime_now": datetime.utcnow().isoformat(),
