@@ -98,14 +98,14 @@ class TwoDWaterLevelRasterWrapper(InitialWrapper):
 class GroundWaterLevelWrapper(InitialWrapper):
     model = GroundWaterLevel
     base_path = "simulations_initial"
-    api_path = "groundwater_level_constant"
+    api_path = "_groundwater_level_constant"
     scenario_name = "groundwaterlevelconstant"
 
 
 class GroundWaterLevelRasterWrapper(InitialWrapper):
     model = GroundWaterRaster
     base_path = "simulations_initial"
-    api_path = "groundwater_level_raster"
+    api_path = "_groundwater_level_raster"
     scenario_name = "groundwaterlevelraster"
 
 
